--
-- This file handles the window to display.
--
local wm = GetWindowManager()

if TNT == nil then TNT = {} end

--
--  Make the primary window
--
function TNT.MakeWindow()
	-- our primary window
	TNT.window = wm:CreateTopLevelWindow("TheNooreTools")
	local tnt = TNT.window
	tnt:SetAnchor(TOPLEFT, GuiRoot, TOPLEFT, TNT.settings.x, TNT.settings.y)
	tnt:SetMovable(true)
	tnt:SetHidden(not TNT.settings.shown)
	tnt:SetMouseEnabled(true)
	tnt:SetClampedToScreen(true)
	tnt:SetDimensions(0,0)
	tnt:SetResizeToFitDescendents(true)
	tnt:SetHandler("OnMoveStop", function()
		TNT.settings.x = tnt:GetLeft()
		TNT.settings.y = tnt:GetTop()
	end)

    -- give it a backdground (backdrop) for the frame
	tnt.bg = wm:CreateControl("TNTBackground", tnt, CT_BACKDROP)
	tnt.bg:SetAnchorFill(tnt)
	tnt.bg:SetCenterColor(0, 0, 0, TNT.settings.alpha / 100)
	tnt.bg:SetEdgeColor(0, 0, 0, TNT.settings.alpha / 100)
	tnt.bg:SetEdgeTexture(nil, 2, 2, 0, 0)
	tnt.bg:SetExcludeFromResizeToFitExtents(true)
	tnt.bg:SetDrawLayer(DL_BACKGROUND)
	
	-- give it a header
	tnt.title = wm:CreateControl("TNTTitle", tnt, CT_LABEL)
	tnt.title:SetAnchor(TOP, tnt, TOP, 0, 5)
	tnt.title:SetFont("EsoUi/Common/Fonts/Univers67.otf|18|soft-shadow-thin")
	tnt.title:SetColor(.9,.9,.7,1)
	tnt.title:SetStyleColor(0,0,0,1)
	tnt.title:SetText("The Noore Tools")
	tnt.title:SetHidden(not TNT.settings.showtitle)

	-- Give it a zone label   @@@ should this be removed???
	tnt.zone = wm:CreateControl("TNTZone", tnt, CT_LABEL)
	if (TNT.settings.showtitle) then
		tnt.zone:SetAnchor(TOP, tnt.title, BOTTOM, 0, 5)
	else
		tnt.zone:SetAnchor(TOP, tnt, TOP, 0, 5)
	end
	tnt.zone:SetFont("EsoUi/Common/Fonts/Univers67.otf|17|soft-shadow-thin")
	tnt.zone:SetColor(.9, .9, .7, 1)
	tnt.zone:SetStyleColor(0,0,0,1)
	tnt.zone:SetText("Zone Name")

	-- make a container for the list entries
	tnt.entries = wm:CreateControl("TNTEntries", tnt, CT_CONTROL)
	tnt.entries:SetAnchor(TOP, tnt.zone, BOTTOM, 0, 0)
	tnt.entries:SetHidden(false)
	tnt.entries:SetResizeToFitDescendents(true)

	-- add a bit of padding
	tnt.entries:SetResizeToFitPadding(20, 10)
	
	-- hide our window when the compass frame gets hidden, if it's not hidden already
	if ZO_CompassFrame:IsHandlerSet("OnShow") then
		local oldHandler = ZO_CompassFrame:GetHandler("OnShow")
		ZO_CompassFrame:SetHandler("OnShow", function(...) oldHandler(...) if TNT.settings.shown then TNT.window:SetHidden(false) end end)
	else
		ZO_CompassFrame:SetHandler("OnShow", function(...) if TNT.settings.shown then TNT.window:SetHidden(false) end end)
	end
	if ZO_CompassFrame:IsHandlerSet("OnHide") then
		local oldHandler = ZO_CompassFrame:GetHandler("OnHide")
		ZO_CompassFrame:SetHandler("OnHide", function(...) oldHandler(...) if TNT.settings.shown then TNT.window:SetHidden(true) end end)
	else
		ZO_CompassFrame:SetHandler("OnHide", function(...) if TNT.settings.shown then TNT.window:SetHidden(true) end end)
	end
end

--
--
--
function TNT.PopulateWindow(monitorText)
	if TNT.window == nil then TNT.MakeWindow() end
	TNT.window.zone:SetText(monitorText)
	
	TNT.window:SetHidden(ZO_CompassFrame:IsHidden() or not TNT.settings.shown)
end


--
-- Show or hide the window
--
function TNT.ToggleWindow()
	local ishidden = TNT.window:IsHidden()
	-- refresh the window if we're about to show it
	if ishidden then TNT.RefreshWindow() end
	TNT.settings.shown = ishidden
	TNT.window:SetHidden(not ishidden)
end